﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 포인트 시리즈
        /// </summary>
        private Points points;

        /// <summary>
        /// 분산 함수
        /// </summary>
        private VarianceFunction varianceFunction;

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 포인트 시리즈를 생성한다.

            this.points = new Points();

            this.points.Title               = "Data";
            this.points.Color               = Color.FromArgb(130, 155, 254);
            this.points.Pointer.Brush.Color = Color.FromArgb(130, 155, 254);

            #endregion
            #region 분산 함수를 생성한다.

            this.varianceFunction = new VarianceFunction();

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Title       = "Variance";
            this.line.Brush.Color = Color.FromArgb(252, 209, 36);
            this.line.Color       = Color.FromArgb(252, 209, 36);
            this.line.DataSource  = this.points;
            this.line.Function    = this.varianceFunction;
            this.line.VertAxis    = VerticalAxis.Right;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Axes.Bottom.Grid.Color    = Color.FromArgb(130, 130, 130);
            this.tChart.Axes.Bottom.Grid.Visible  = true;
            this.tChart.Axes.Bottom.MaximumOffset = 5;
            this.tChart.Axes.Bottom.MinimumOffset = 5;
            this.tChart.Legend.Visible            = false;

            this.tChart.Series.Add(this.points);
            this.tChart.Series.Add(this.line);

            #endregion

            this.points.FillSampleValues();

            this.refreshButton.Click += refreshButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 갱신하기 버튼 클릭시 처리하기 - refreshButton_Click(sender, e)

        /// <summary>
        /// 갱신하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void refreshButton_Click(object sender, EventArgs e)
        {
            this.points.FillSampleValues();
        }

        #endregion
    }
}